﻿<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="html"/>

  <xsl:template match="/">

    <html>
      <head>
        <script language="javascript">
          function viewSection(sectionId)
          {
          if(document.getElementById(sectionId).style.display == 'none')
          { document.getElementById(sectionId).style.display = 'inline'; }
          else
          { document.getElementById(sectionId).style.display = 'none'; }
          }
        </script>
        <style type="text/css">
          .checkTypeLabel
          {
          font: italic normal 1.5em georgia, sans-serif;
          color: #7D775C;
          letter-spacing: 1px;

          }

          .checkType
          {

          }

          .check
          {
          font: italic normal 1.5em georgia, sans-serif;
          padding-left:45;
          }

          .checkDetail
          {

          padding-left:20;
          }

          .checkDetailItem
          {
          font: .65em;

          }

          .checkLabel
          {
          font-weight: bold;
          }
          .checkValue
          {
          margin-left: 15;
          }
          .failSummary
          {
          margin-left: 25;
          font-weight: bold;
          font-color: LightSalmon;
          }
        </style>
      </head>

      <body>

        <H2>
          Check set result(s): '<xsl:value-of select="checkSet/@name"/>'
        </H2>
        <br/>

        Summary: <xsl:value-of select="count(checkSet/check)"/> test(s) run
        (<xsl:value-of select="count(checkSet/check[@passResult='Pass'])"/> passed)
        (<xsl:value-of select="count(checkSet/check[@passResult='Fail'])"/> failed)

        <xsl:apply-templates select="checkSet" />

      </body>
    </html>

  </xsl:template>


  <xsl:template match="checkSet">
    <xsl:for-each select="check[not(@checkType = preceding-sibling::check/@checkType)]">
      <xsl:sort select="check/@checkType"/>
      <xsl:variable name="checkType" select="@checkType" />
      <xsl:variable name="failures" select="count(/checkSet/check[@checkType=$checkType and @passResult='Fail'])" />
      <xsl:variable name="checkStyleDisplay">
        <xsl:choose>
          <xsl:when test="$failures !=0">
            inline
          </xsl:when>
          <xsl:otherwise>
            none
          </xsl:otherwise>
        </xsl:choose>
      </xsl:variable>

      <div class="checkType">
        <div class="checkTypeLabel">
          <img src="{concat(/checkSet/@applicationPath, '/XSLT/images/', $checkType, '.gif')}" />
        
          <a>
            <xsl:attribute name="href">
              javascript:viewSection('<xsl:value-of select="concat('checkType_', $checkType)" />');
            </xsl:attribute>
            <xsl:value-of select="$checkType"/>
          </a>

        </div>

        <div class="checks" style="{concat('display:', $checkStyleDisplay)}" id="{concat('checkType_', $checkType)}">
          <xsl:for-each select="/checkSet/check[@checkType=$checkType]">
            <div class="check" >
              <img height="16" width="16"   src="{concat(/checkSet/@applicationPath, '/XSLT/images/', @passResult, '.gif')}" />
              
              <xsl:value-of select="position()"/>:
              <xsl:apply-templates select="." mode="All" />
            </div>
          </xsl:for-each>
        </div>
      </div>

    </xsl:for-each>
  </xsl:template>

  <xsl:template match="check" mode="All">

    

    <a>
      <xsl:attribute name="href">
        javascript:viewSection('check_<xsl:value-of select="count(preceding-sibling::*)" />');
      </xsl:attribute>
      <xsl:value-of select="@name"/>
    </a>
    <div class="checkDetail" style="display:none" id="{concat('check_', count(preceding-sibling::*))}">

      <xsl:choose>
        <xsl:when test="@checkType = 'GAC'">
          <xsl:apply-templates select="." mode="GAC" />
        </xsl:when>
        <xsl:when test="@checkType = 'SQL'">
          <xsl:apply-templates select="." mode="SQL" />
        </xsl:when>
        <xsl:when test="@checkType = 'Registry'">
          <xsl:apply-templates select="." mode="Registry" />
        </xsl:when>
        <xsl:when test="@checkType = 'File' or @checkType = 'configurationFile' ">
          <xsl:apply-templates select="." mode="File" />
        </xsl:when>
      </xsl:choose>
      <xsl:apply-templates select="resultInformation" />
    </div>
  </xsl:template>

  <xsl:template match="resultInformation">
    <div class="resultInformation">
      <xsl:for-each select="detail">
        <xsl:value-of select="."/>
        <br/>
      </xsl:for-each>
    </div>
    
  </xsl:template>

  <xsl:template match="check" mode="GAC">
    <div class="checkDetailItem">
      <span class="checkLabel">Component Name:</span>
      <span class="checkValue">
        <xsl:value-of select="@componentName"/>
      </span>
    </div>

    <div class="checkDetailItem">
      <span class="checkLabel">
        Version Number:
      </span>
      <span class="checkValue">
        <xsl:value-of select="@versionNumber"/>
      </span>
    </div>
    
  </xsl:template>

  <xsl:template match="check" mode="Registry">
    <div class="checkDetailItem">
      <span class="checkLabel">
        Hive path:
      </span>
      <span class="checkValue">
        <xsl:value-of select="@hivePath"/>
      </span>
    </div>
    <div class="checkDetailItem">
      <span class="checkLabel">
        Hive name:
      </span>
      <span class="checkValue">
        <xsl:value-of select="@hiveName"/>
      </span>
    </div>
    <div class="checkDetailItem">
      <span class="checkLabel">
        Hive value:
      </span>
      <span class="checkValue">
        <xsl:value-of select="@hiveValue"/>
      </span>
    </div>

  </xsl:template>

  <xsl:template match="check" mode="SQL">
    <div class="checkDetailItem">
      <span class="checkLabel">
        Server Instance:
      </span>
      <span class="checkValue">
        <xsl:value-of select="@serverInstance"/>
      </span>
    </div>
    <div class="checkDetailItem">
      <span class="checkLabel">
        Database Name:
      </span>
      <span class="checkValue">
        <xsl:value-of select="@databaseName"/>
      </span>
    </div>
    <div class="checkDetailItem">
      <span class="checkLabel">
        Table count:
      </span>
      <span class="checkValue">
        <xsl:value-of select="@tableCount"/>
      </span>
    </div>
    <div class="checkDetailItem">
      <span class="checkLabel">
        Stored Procedure count:
      </span>
      <span class="checkValue">
        <xsl:value-of select="@storedProcedureCount"/>
      </span>
    </div>
    <div class="checkDetailItem">
      <span class="checkLabel">
        View count:
      </span>
      <span class="checkValue">
        <xsl:value-of select="@viewCount"/>
      </span>
    </div>
  </xsl:template>

  <xsl:template match="check" mode="File">


  </xsl:template>
  

  <xsl:template match="resultInformation">
    <table>
      <xsl:for-each select="detail">
      
        <tr>
          <td align="left">
            <xsl:value-of select="."/>
          </td>
        </tr>
      
      </xsl:for-each>

    </table>
    <xsl:apply-templates select="furtherDetail"/>
    
  </xsl:template>
</xsl:stylesheet>